#version 330 core

in vec2 frag_light;
in vec2 frag_occlusion;
flat in int frag_effect;
in vec3 frag_texcoord;
in float frag_depth;

out vec4 color;

uniform sampler2DArray texture1;
uniform sampler2D light;
uniform sampler2D occlusion;
uniform sampler2D waves;
uniform vec3 fog_color;
uniform float fog_depth;
uniform int effect_frame;

void main()
{
        // base is the data from the main texture.
        // This is the only place were we handle transparency:
        // every pixel with an alpha value less or equal than 0.5 is ignored.
        vec4 base = texture(texture1, frag_texcoord);
        if (base.a <= 0.5) discard;

        if (frag_effect != 0) {
                // occl_tc is the coordinate in the ambient occlusion texture
                // occl_val is the value from the occlusion texture
                vec2 occl_tc = frag_occlusion / 16.0 + frag_texcoord.xy / 32.0 + 1.0 / 64.0;
                vec3 occl_val = texture(occlusion, occl_tc).xyz;

                // effect #2 is water waves.
                // It is applied first because it might replace the color,
                // and we want other effects to change that replaced color.
                if ((frag_effect & 2) != 0) {
                        vec2 wave_tc = frag_texcoord.xy + effect_frame / 128.0;
                        if (occl_val.x + texture(waves, wave_tc).x * 0.5 < 1)
                                base = vec4(1,1,1,1);
                }

                // effect #1 is ambient occlusion
                if ((frag_effect & 1) != 0) {
                        base.xyz *= occl_val;
                }
        }

        // brightness is the data from the light texture; this merges both the
        // skylight and local light effects.
        base.xyz *= texture(light, (frag_light + 0.5) / 16.0).xyz;

        // The fog effect is pretty simple, average the fragment color with the
        // fog color according to the distance to the camera divided by the
        // maximum fog depth.
        float fog_density = pow(clamp(frag_depth / fog_depth, 0, 1), 2);
        color = vec4(mix(base.xyz, fog_color, fog_density), 1.0);
}
