#version 330 core

layout(location = 0) in vec3 vert_position;
layout(location = 1) in int vert_light;
layout(location = 2) in int vert_occlusion;
layout(location = 3) in int vert_effect;
layout(location = 4) in vec2 vert_texcoord;
layout(location = 5) in int vert_texid;

out vec3 frag_texcoord;
out vec2 frag_light;
out vec2 frag_occlusion;
flat out int frag_effect;
out float frag_depth;

uniform vec3 model;
uniform mat4 vp;
uniform vec3 camera;
uniform float planet_radius;

void main()
{
        // the actual position is the vertex position *plus* the model offset.
        // the model offset is separate from the vp matrix because if we
        // integrated both, numeric errors would cause stitching in page
        // boundaries.
        vec3 position = model + vert_position;

        // the distance of the position to the camera will be used to compute
        // many different effects.
        frag_depth = distance(camera, position);

        // horizon dipping moves vertices slightly down proportionally to their
        // distance to the camera.
        position.y -= planet_radius - sqrt(planet_radius * planet_radius - frag_depth * frag_depth);

        // The rest of values are just passed to the fragment shader in the
        // right format.
	gl_Position = vp * vec4(position, 1);
        frag_texcoord = vec3(vert_texcoord, vert_texid);
        frag_light = vec2(vert_light % 16, vert_light / 16);
        frag_occlusion = vec2(vert_occlusion % 16, vert_occlusion / 16);
        frag_effect = vert_effect;
}

