#version 330 core

layout(location = 0) in vec3 vert_position;
layout(location = 1) in int vert_texid;
layout(location = 2) in int vert_light;
layout(location = 3) in vec2 vert_corner;

out vec3 frag_texcoord;
out vec2 frag_light;
out float frag_depth;

uniform mat4 view;
uniform mat4 projection;
uniform vec3 camera;

void main()
{
        // Calculate center of mob in view coordinates, then offset by the
        // given corner and complete the transformation to get the final vertex
        // position.
        vec4 center = view * vec4(vert_position, 1);
        center.xy += 1 * (vert_corner - vec2(0.5));
        gl_Position = projection * center;

        // If the textureid is negative, we flip the texture horizontally by
        // inverting the x corner coordinate; in all cases, we invert the y
        // corner coordinate because for textures, negative is up.
        if (vert_texid < 0)
                frag_texcoord = vec3(1 - vert_corner.x, 1 - vert_corner.y, -vert_texid);
        else
                frag_texcoord = vec3(vert_corner.x, 1 - vert_corner.y, vert_texid);

        // The light value is directly passed to the fragment shader
        frag_light = vec2(vert_light % 16, vert_light / 16);

        // the depth value is just he center's distance to the camera
        frag_depth = distance(camera, vert_position);
}

